'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GeoJSONTransform = undefined;
exports.getLuma = getLuma;
exports.getTheme = getTheme;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const L = require('leaflet');
/* eslint class-methods-use-this: 0 */


L.Icon.Default.imagePath = '../node_modules/leaflet/dist/images/';

const MIMETYPE = 'application/geo+json';

function getLuma(el) {
  // https://en.wikipedia.org/wiki/Luma_(video)
  const style = window.getComputedStyle(el);
  const [r, g, b] = style.backgroundColor.replace(/^(rgb|rgba)\(/, '').replace(/\)$/, '').replace(/\s/g, '').split(',');

  // Digital ITU BT.601
  // http://www.itu.int/rec/R-REC-BT.601
  const y = 0.299 * r + 0.587 * g + 0.114 * b;
  return y / 255;
}

function getTheme(theme = 'light', el) {
  switch (theme) {
    case 'light':
    case 'dark':
      return theme;
    default:
      if (getLuma(el) < 0.5) {
        return 'dark';
      }
      return 'light';
  }
}

class GeoJSONTransform extends _react2.default.Component {

  componentDidMount() {
    this.map = L.map(this.el);
    this.map.scrollWheelZoom.disable();

    const theme = getTheme(this.props.theme, this.el);

    this.tileLayer = L.tileLayer('https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpandmbXliNDBjZWd2M2x6bDk3c2ZtOTkifQ._QA7i5Mpkd_m30IGElHziw', {
      attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
      id: `mapbox.${theme}`
    }).addTo(this.map);

    const geoJSON = this.props.data;

    this.geoJSONLayer = L.geoJson(geoJSON).addTo(this.map);
    this.map.fitBounds(this.geoJSONLayer.getBounds());
  }

  shouldComponentUpdate(nextProps) {
    if (nextProps.theme !== this.props.theme || this.props.data !== nextProps.data) {
      return true;
    }
    return false;
  }

  componentDidUpdate(prevProps) {
    if (prevProps.theme !== this.props.theme) {
      const theme = getTheme(this.props.theme, this.el);
      this.map.removeLayer(this.tileLayer);
      this.tileLayer = L.tileLayer('https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpandmbXliNDBjZWd2M2x6bDk3c2ZtOTkifQ._QA7i5Mpkd_m30IGElHziw', {
        attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
        id: `mapbox.${theme}`
      }).addTo(this.map);
    }

    if (prevProps.data !== this.props.data) {
      const geoJSON = this.props.data;

      this.map.removeLayer(this.geoJSONLayer);
      this.geoJSONLayer = L.geoJson(geoJSON).addTo(this.map);
      this.map.fitBounds(this.geoJSONLayer.getBounds());
    }
  }

  render() {
    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement('link', {
        rel: 'stylesheet',
        href: '../node_modules/leaflet/dist/leaflet.css'
      }),
      _react2.default.createElement('div', {
        ref: el => {
          this.el = el;
        },
        style: { height: '600px', width: '100%' }
      })
    );
  }
}

exports.GeoJSONTransform = GeoJSONTransform;
GeoJSONTransform.defaultProps = { theme: 'light' };
GeoJSONTransform.MIMETYPE = MIMETYPE;
exports.default = GeoJSONTransform;